// Copyright 2023 Google LLC All Rights Reserved.
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

terraform {
  required_providers {
    google = {
      source  = "hashicorp/google"
      version = "5.17.0"
    }

    random = {
      source  = "hashicorp/random"
      version = "3.6.3"
    }
  }

  backend "gcs" {
  }
}

data "google_project" "default" {
}

resource "random_uuid" "client_id" {
  keepers = {
    force_new = var.force_new_client_id ? timestamp() : "false"
  }
}

module "mfc-service" {
  source = "./modules/mainframe-connector/service"

  service_account = var.connector_service_account_email
  project = var.project
  name = var.instance_id
  region = var.region
  debug = var.debug
  ingress = var.connector_service_ingress
  client_id = random_uuid.client_id.result
}

module "mfc-transcode-job" {
  source = "./modules/mainframe-connector/transcode-job"

  service_account = var.connector_transcode_job_account_email
  project = var.project
  name = var.instance_id
  region = var.region
  debug = var.debug
  client_id = random_uuid.client_id.result
}

module "mfc-connector-standalone" {
  source = "./modules/mainframe-connector/standalone-job"

  service_account = var.connector_standalone_account_email
  project = var.project
  name = var.instance_id
  region = var.region
  debug = var.debug
  client_id = random_uuid.client_id.result
}

provider "google" {
  project = var.project
  region  = var.region
}
