// Copyright 2024 Google LLC All Rights Reserved.
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

variable "project" {
  description = "GCP project to deploy the Mainframe Connector service."
  type        = string
}

variable "service_account" {
  description = <<-EOT
  The service account email to use for the Mainframe Connector service.
  e.g. mainframe-connector@my-project.iam.gserviceaccount.com
  EOT
  type        = string
}

variable "region" {
  description = "GCP region to deploy the Mainframe Connector service."
  type        = string
  default     = "us-central1"
}

variable "debug" {
  description = "Turn on debug logging."
  type        = bool
  default     = false
}

variable "name" {
  description = "Name to use. This should be set if you intend to deploy multiple instances of Mainframe Connector in the same GCP project."
  type        = string
  default     = "mf-connector"
}

variable "release" {
  description = "Mainframe Connector release to use. Do not change unless you know what you are doing."
  type        = string
  default     = "9381f5e0058676bf95cc97c64b07ef5ca068d8f9623677d3e00505ea2f992864"
}

variable "container_registry" {
  description = "Container registry containing the Mainframe Connector image. Can be set if using a container registry mirror."
  type        = string
  default     = "us-docker.pkg.dev/migrate-modernize-public/mainframe-connector-prod/mainframe-connector@sha256"
}

variable "additional_labels" {
  description = "Additional labels to add to created resources where applicable."
  type        = map(string)
  default     = {}
}

variable "memory_limit" {
  description = <<-EOT
  The maximum amount of memory the service can use.
  More information at https://cloud.google.com/run/docs/configuring/services/memory-limits#terraform
  EOT
  type        = string
  default     = "32Gi"
}

variable "cpu_limit" {
  description = <<-EOT
https://cloud.google.com/run/docs/configuring/services/cpu
  EOT
  type        = string
  default     = "8"
}

variable "input_gsuri" {
  description = <<-EOT
  gsuri (e.g. gs://bucket/prefix) of the location where the input files are.
  EOT
  type        = string
  default     = ""
}

variable "copybook_gsuri" {
  description = <<-EOT
  gsuri (e.g. gs://bucket/prefix) with the location of the copybook.
  EOT
  type        = string
  default     = ""
}

variable "output_gsuri" {
  description = <<-EOT
  gsuri (e.g. gs://bucket/prefix) with the location of the copybook.
  EOT
  type        = string
  default     = ""
}

variable "client_id" {
  description = "A unique identifier used for analytics."
  type    = string
  default = ""
}
